@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -33,10 +33,12 @@
 module asciiutils
  implicit none
  public :: read_asciifile,get_ncolumns,get_nrows,ncolumnsline,safename,basename
- public :: cstring,fstring
+ public :: cstring,fstring,add_escape_chars
  public :: string_replace, string_delete, nheaderlines, string_sub
  public :: ucase,lcase
  public :: get_line_containing
+ public :: enumerate,isdigit,split
+ public :: get_column_labels
 
  private
 
@@ -47,7 +49,7 @@ module asciiutils
 !--------------------------------------------------
  interface read_asciifile
    module procedure read_asciifile_char, read_asciifile_real,&
-                    read_asciifile_real_string
+                    read_asciifile_real_string, read_asciifile_realarr
  end interface read_asciifile
 
 contains
@@ -180,6 +182,56 @@ subroutine read_asciifile_real(filename,nlinesread,realarr,ierror)
 
 end subroutine read_asciifile_real
 
+!---------------------------------------------------------------------------
+! Generic subroutine to read all lines of an ascii file
+! returns 2D array of real numbers (i.e. tabulated data)
+!---------------------------------------------------------------------------
+subroutine read_asciifile_realarr(filename,nlinesread,realarr,ierror)
+ implicit none
+ character(len=*), intent(in) :: filename
+ integer, intent(out) :: nlinesread
+ real, dimension(:,:), intent(out) :: realarr
+ integer, intent(out), optional :: ierror
+ integer, parameter :: iunit = 66 ! logical unit number for read operation
+ integer :: ierr,i,ncols,ncolsfile,nheader
+ logical :: iexist
+
+ nlinesread = 0
+ if (present(ierror)) ierror = 0
+
+ !--if file does not exist, do nothing and return
+ inquire(file=filename,exist=iexist)
+ if (.not.iexist) then
+    if (present(ierror)) ierror = -1
+    return
+ endif
+
+ open(unit=iunit,file=filename,status='old',form='formatted',iostat=ierr)
+ !--error opening file (but file does exist)
+ if (ierr /= 0) then
+    print "(a)",' ERROR opening '//trim(filename)
+    if (present(ierror)) ierror = ierr
+    return
+ else
+    ! get number of columns
+    call get_ncolumns(iunit,ncolsfile,nheader)
+    ! skip header lines
+    do i=1,nheader
+       read(iunit,*,iostat=ierr)
+    enddo
+    ! read 2D array from file
+    ncols = min(ncolsfile,size(realarr(:,1)))
+    nlinesread = 0
+    do while (ierr==0)
+       nlinesread = nlinesread + 1
+       read(iunit,*,iostat=ierr) realarr(1:ncols,nlinesread)
+    enddo
+    nlinesread = max(nlinesread - 1,0)
+    close(iunit)
+ endif
+
+end subroutine read_asciifile_realarr
+
 !---------------------------------------------------------------------------
 ! Generic subroutine to read all lines of an ascii file
 ! returns array of real numbers and corresponding string
@@ -258,14 +310,20 @@ end subroutine read_asciifile_real_string
 ! file must already be open and at the start
 ! slightly ad-hoc but its the best way I could think of!
 !---------------------------------------------------------------------------
-subroutine get_ncolumns(lunit,ncolumns,nheaderlines)
+subroutine get_ncolumns(lunit,ncolumns,nheaderlines,maxheaderlines)
  implicit none
  integer, intent(in) :: lunit
  integer, intent(out) :: ncolumns,nheaderlines
- integer :: ierr,ncolprev,ncolsthisline
+ integer, intent(in), optional :: maxheaderlines
+ integer :: ierr,ncolprev,ncolsthisline,maxlines
  character(len=5000) :: line
  logical :: nansinfile,infsinfile
 
+ if (present(maxheaderlines)) then
+    maxlines = maxheaderlines
+ else
+    maxlines = 1000
+ endif
  nheaderlines = 0
  line = ' '
  ierr = 0
@@ -277,7 +335,8 @@ subroutine get_ncolumns(lunit,ncolumns,nheaderlines)
 !
 !--loop until we find two consecutive lines with the same number of columns (but non zero)
 !
- do while ((len_trim(line).eq.0 .or. ncolsthisline.ne.ncolprev .or. ncolumns.le.0) .and. ierr.eq.0)
+ do while ((len_trim(line).eq.0 .or. ncolsthisline.ne.ncolprev .or. ncolumns.le.0) &
+           .and. ierr.eq.0 .and. nheaderlines <= maxlines)
     ncolprev = ncolumns
     read(lunit,"(a)",iostat=ierr) line
     if (index(line,'NaN').gt.0) nansinfile = .true.
@@ -346,7 +405,7 @@ integer function ncolumnsline(line)
 
  i = 1
  ncolumnsline = 0
- do while(abs(dummyreal(i)+666666.).gt.tiny(0.))
+ do while(abs(dummyreal(i)+666666.).gt.tiny(0.) .or. dummyreal(i).ne.dummyreal(i))
     ncolumnsline = ncolumnsline + 1
     i = i + 1
     if (i.gt.size(dummyreal)) then
@@ -430,6 +489,22 @@ function safename(string)
 
 end function safename
 
+!---------------------------------------------------------------------------
+!
+! function to insert escape characters so filenames appear correctly in legend
+!
+!---------------------------------------------------------------------------
+function add_escape_chars(string)
+ implicit none
+ character(len=*), intent(in) :: string
+ character(len=len(string)) :: add_escape_chars
+
+ add_escape_chars = string
+ call string_replace(add_escape_chars,'_','\_')
+ call string_replace(add_escape_chars,'^','\^')
+
+end function add_escape_chars
+
 !---------------------------------------------------------------------------
 !
 ! function stripping the directory off a filename
@@ -500,13 +575,17 @@ subroutine string_replace(string,skey,sreplacewith)
  implicit none
  character(len=*), intent(inout) :: string
  character(len=*), intent(in)    :: skey,sreplacewith
- integer :: ipos,lensub
+ character(len=len(string)) :: remstring
+ integer :: ipos,ioffset,lensub
 
  ipos = index(trim(string),skey)
  lensub = len(skey)
  do while(ipos.gt.0)
-    string = string(1:ipos-1)//sreplacewith//string(ipos+lensub:len_trim(string))
-    ipos = index(trim(string),skey)
+    remstring = string(ipos+lensub:len_trim(string))
+    ioffset = ipos - 1 + len(sreplacewith)
+    string = string(1:ipos-1)//sreplacewith//remstring
+    ipos = index(trim(remstring),skey)
+    if (ipos > 0) ipos = ipos + ioffset
  enddo
 
 end subroutine string_replace
@@ -597,7 +676,22 @@ end function lcase
 
 !---------------------------------------------------------------------------
 !
-! Converts a string to lower case
+! indicate if a character is a digit (number) or not
+!
+!---------------------------------------------------------------------------
+logical function isdigit(string)
+ character(len=1), intent(in) :: string
+ integer :: ia
+
+ isdigit = .false.
+ ia = iachar(string)
+ if (ia >= iachar('0').and.ia <= iachar('9')) isdigit = .true.
+
+end function isdigit
+
+!---------------------------------------------------------------------------
+!
+! search a file for the line containing a particular string
 !
 !---------------------------------------------------------------------------
 integer function get_line_containing(filename,string)
@@ -618,4 +712,168 @@ integer function get_line_containing(filename,string)
  
 end function get_line_containing
 
+!---------------------------------------------------------------------------
+!
+! Convert an integer into the corresponding entry in a list of strings
+!
+!---------------------------------------------------------------------------
+function enumerate(i,stringarr,default) result(string)
+ integer, intent(in) :: i
+ character(len=*), intent(in), dimension(:) :: stringarr
+ integer, intent(in), optional :: default
+ character(len=len(stringarr)) :: string
+
+ string = ''
+ if (i >= 1 .and. i <= size(stringarr)) then
+    string = trim(stringarr(i))
+ elseif (present(default)) then
+    if (default >= 1 .and. i <= size(stringarr)) then
+       string = trim(stringarr(default))
+    endif
+ endif
+
+end function enumerate
+
+!---------------------------------------------------------------------------
+!
+! Split a string into substrings based on a delimiter
+!
+!---------------------------------------------------------------------------
+subroutine split(string,delim,stringarr,nsplit)
+ character(len=*), intent(in)  :: string
+ character(len=*), intent(in)  :: delim
+ character(len=*), intent(out), dimension(:) :: stringarr
+ integer,          intent(out) :: nsplit
+ integer :: i,j
+
+ i = 1
+ nsplit = 0
+ do while(nsplit < size(stringarr) .and. i < len(string))
+    ! find next non-blank character
+    do while (string(i:i)==' ')
+       i = i + 1
+       if (i > len(string)) exit
+    enddo
+    i = i - 1
+    if (i < 1) i = 1 ! first character is non-blank
+
+    ! look for next occurrence of delimiter
+    j = index(string(i:),delim)
+    if (j==0) j = len(string(i:))
+    nsplit = nsplit + 1
+    if (nsplit <= size(stringarr)) then
+       stringarr(nsplit) = string(i:min(i+j,len(string)))
+    endif
+    i = i + j + 1
+ enddo
+
+end subroutine split
+
+!---------------------------------------------------------------------------
+!
+! extract a list of labels from the header line of a file
+!
+!---------------------------------------------------------------------------
+subroutine get_column_labels(line,nlabels,labels)
+ character(len=*), intent(in)  :: line
+ integer,          intent(out) :: nlabels
+ character(len=*), dimension(:), intent(out) :: labels
+ integer :: i1,i2,i,nlabelstmp
+ character(len=1) :: leadingchar
+
+ nlabels = 0
+ i1 = 1
+ !
+ ! strip leading comment character ('#')
+ !
+ leadingchar = trim(adjustl(line))
+ if (leadingchar=='#') then
+    i1 = index(line,'#') + 1
+ endif
+ ! strip anything preceding an equals sign
+ i1 = max(i1,index(line,'=')+1)
+ i2 = i1
+
+ if (index(line,']') > 0) then
+ !
+ ! format style 1: # [ mylabel1 ] [ mylabel2 ] [ mylabel3 ]
+ !
+    call split(line(i1:),']',labels,nlabels)
+ elseif (index(line,',') > 1) then
+ !
+ ! format style 2: mylabel1,mylabel2,mylabel3
+ !
+    call split(line(i1:),',',labels,nlabelstmp)
+    nlabels = count_sensible_labels(nlabelstmp,labels)
+ else
+ !
+ ! format style 3: #     mylabel1     mylabel2     mylabel3
+ !
+    call split(line(i1:),'  ',labels,nlabelstmp)
+ !
+ ! this style is dangerous, so perform sanity checks
+ ! on the labels to ensure they are sensible
+ !
+    nlabels = count_sensible_labels(nlabelstmp,labels)
+ endif
+ !
+ ! clean up
+ !
+ do i=1,nlabels
+    ! delete brackets
+    if (nlabels <= size(labels)) then
+       call string_delete(labels(i),',')
+       call string_delete(labels(i),'[')
+       call string_delete(labels(i),']')
+       labels(i) = trim(adjustl(labels(i)))
+       ! delete leading numbers
+       i1 = 1
+       do while (isdigit(labels(i)(i1:i1)))
+          labels(i)(i1:i1) = ' '
+          i1 = i1 + 1
+       enddo
+       labels(i) = trim(adjustl(labels(i)))
+    endif
+ enddo
+
+end subroutine get_column_labels
+
+!---------------------------------------------------------------------------
+!
+! count the number of sensible labels in a list of possible labels
+!
+!---------------------------------------------------------------------------
+integer function count_sensible_labels(n,labels) result(m)
+ integer, intent(in) :: n
+ character(len=*), dimension(n), intent(in) :: labels
+ integer :: i
+
+ m = 0
+ do i=1,n
+    if (is_sensible_label(labels(i))) m = m + 1
+ enddo
+
+end function count_sensible_labels
+
+!---------------------------------------------------------------------------
+!
+! determine if a particular string makes sense as a column label or not
+!
+!---------------------------------------------------------------------------
+logical function is_sensible_label(string)
+ character(len=*), intent(in) :: string
+ real    :: dum
+ integer :: ierr
+
+ is_sensible_label = .true.
+
+ ! should not contain equals sign
+ !if (index(string,'=') > 0) is_sensible_label = .false.
+
+ ! should not be able to read it as a real number
+ read(string,*,iostat=ierr) dum
+ if (ierr==0) is_sensible_label = .false.
+
+end function is_sensible_label
+
 end module asciiutils
