@@ -161,6 +161,21 @@ subroutine defaults_set(use_evdefaults)
 
   return
 end subroutine defaults_set
+
+!
+! set defaults for 360 video mode
+!
+subroutine defaults_set_360()
+ use settings_page,   only:defaults_set_page_360
+ use settings_render, only:defaults_set_render_360
+ use settings_data,   only:icoordsnew
+
+ icoordsnew = 3
+ call defaults_set_render_360
+ call defaults_set_page_360()
+
+end subroutine defaults_set_360
+
 !
 !     writes default options to file (should match defaults_read)
 !
@@ -218,7 +233,7 @@ end subroutine defaults_write
 subroutine defaults_read(filename)
  use filenames,          only:rootname,maxfile
  use multiplot,          only:multi
- use settings_data,      only:dataopts
+ use settings_data,      only:dataopts,idustfrac_plot
  use settings_part,      only:plotopts
  use settings_page,      only:pageopts
  use settings_render,    only:renderopts
@@ -307,7 +322,7 @@ subroutine defaults_read(filename)
 
 88 continue
  print "(a)",' *** error opening defaults file '//trim(filename)//': using default settings'
-
+ 
  return
 end subroutine defaults_read
 
