@@ -83,13 +83,13 @@ end module particle_data
 module filenames
  implicit none
  integer, parameter :: maxfile = 10001
- integer :: nfiles,nsteps,ifileopen
+ integer :: nfiles,nsteps,ifileopen,iposopen
  character(len=120), dimension(maxfile) :: rootname
  character(len=100) :: fileprefix
- character(len=120) :: defaultsfile,limitsfile,unitsfile
+ character(len=120) :: defaultsfile,limitsfile,unitsfile,coloursfile
  integer, dimension(maxfile) :: nstepsinfile
  character(len=68)  :: tagline = &
-  'SPLASH: A visualisation tool for SPH data (c)2004-2015 Daniel Price'
+  'SPLASH: A visualisation tool for SPH data (c)2004-2017 Daniel Price'
 
  public
 
@@ -99,10 +99,14 @@ contains
   implicit none
   character(len=*), intent(in) :: prefix
 
-  defaultsfile = trim(adjustl(prefix))//'.defaults'
-  limitsfile   = trim(adjustl(prefix))//'.limits'
-  unitsfile    = trim(adjustl(prefix))//'.units'
   fileprefix   = trim(adjustl(prefix))
+  if (fileprefix(len_trim(fileprefix):len_trim(fileprefix)).eq.'.') then
+     fileprefix = fileprefix(1:len_trim(fileprefix)-1)
+  endif
+  defaultsfile = trim(adjustl(fileprefix))//'.defaults'
+  limitsfile   = trim(adjustl(fileprefix))//'.limits'
+  unitsfile    = trim(adjustl(fileprefix))//'.units'
+  coloursfile  = trim(adjustl(fileprefix))//'.colours'
 
   return
  end subroutine set_filenames
@@ -122,6 +126,8 @@ module settings_data
  integer :: ndataplots
  integer :: ndim, ndimv
  integer :: ndusttypes
+ integer :: idustfrac_plot = 0
+ integer :: ideltav_plot = 0
  integer :: icoords,icoordsnew,iformat,ntypes,iexact
  integer :: istartatstep,iendatstep,nfreq
  integer :: itracktype,itrackoffset,iverbose
@@ -138,7 +144,8 @@ module settings_data
  logical, dimension(maxparttypes) :: UseTypeInRenderings
  real, dimension(3) :: xorigin
 
- namelist /dataopts/ buffer_data,iCalcQuantities,iRescale,xorigin,itracktype,itrackoffset
+ namelist /dataopts/ buffer_data,iCalcQuantities,iRescale,xorigin, &
+                     itracktype,itrackoffset,idustfrac_plot,ideltav_plot
 
  public
 
