@@ -45,7 +45,8 @@ module labels
  integer :: isurfdens,itoomre
  integer :: ipdf,icolpixmap
  integer :: irhorestframe,idustfrac,ideltav
- integer :: idustfracsum,ideltavsum,idustfrac_plot,ideltav_plot
+ integer :: idustfracsum,ideltavsum
+ integer :: igrainsize,igraindens
 
  public
 
@@ -78,6 +79,8 @@ subroutine reset_columnids
  iax = 0      ! ax (acceleration)
  iBpol = 0    ! B_polx
  iBtor = 0    ! B_torx
+ igrainsize = 0 ! grainsize
+ igraindens = 0 ! graindens
  iacplane = 0
  ike = 0
  idivB = 0
@@ -88,10 +91,8 @@ subroutine reset_columnids
  irhorestframe = 0
  idustfrac = 0
  idustfracsum = 0
- idustfrac_plot = 0
  ideltav = 0
  ideltavsum = 0
- ideltav_plot = 0
 
  return
 end subroutine reset_columnids
@@ -261,17 +262,32 @@ function integrate_label(labelin,iplot,izcol,normalise,iRescale,labelzint,&
         endif
         if (iplot.eq.irho .and. (index(labelin,'density').ne.0 .or. index(labelin,'rho').ne.0)) then
            integrate_label = 'column density'
-           !--try to get units label right for column density
-           !  would be nice to have a more robust way of knowing what the units mean
-           if (iRescale .and. index(labelzint,'cm').gt.0  &
-                        .and. trim(adjustl(unitslabel(irho))).eq.'[g/cm\u3\d]') then
-              integrate_label = trim(integrate_label)//' [g/cm\u2\d]'
-           endif
+           integrate_label = trim(integrate_label)//get_unitlabel_coldens(iRescale,labelzint,unitslabel(irho))
         endif
      endif
   endif
 end function integrate_label
 
+!-----------------------------------------------------------------
+!
+! utility to convert the units label to g/cm^2 where appropriate
+! would be nice to have a more robust way of knowing what the units mean
+!
+!-----------------------------------------------------------------
+function get_unitlabel_coldens(iRescale,labelzint,unitlabel)
+ logical, intent(in) :: iRescale
+ character(len=*), intent(in) :: labelzint,unitlabel
+ character(len=lenunitslabel) :: get_unitlabel_coldens
+
+ if (iRescale .and. index(labelzint,'cm').gt.0  &
+     .and. trim(adjustl(unitlabel)).eq.'[g/cm\u3\d]') then
+    get_unitlabel_coldens = ' [ g/cm\u2\d]'
+ else
+    get_unitlabel_coldens = ' '
+ endif
+
+end function get_unitlabel_coldens
+
 !-----------------------------------------------------------------
 !
 ! utility to "guess" which particle type contains sink particles
