@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -32,18 +32,19 @@ module mainmenu
 contains
 
 subroutine menu
-  use filenames,        only:defaultsfile,limitsfile,fileprefix,set_filenames
+  use filenames,        only:defaultsfile,limitsfile,unitsfile,fileprefix,set_filenames
   use labels,           only:label,labelvec,iamvec,isurfdens,itoomre,ipdf,icolpixmap,is_coord,ix
   use limits,           only:write_limits,lim2,lim,reset_lim2,lim2set
   use options_data,     only:submenu_data
   use settings_data,    only:ndim,numplot,ndataplots,nextra,ncalc,ivegotdata, &
-                             buffer_data,ncolumns,icoords,icoordsnew
+                             buffer_data,ncolumns,icoords,icoordsnew,iRescale
   use settings_limits,  only:submenu_limits,iadapt
   use settings_part,    only:submenu_particleplots
   use settings_page,    only:submenu_page,submenu_legend,interactive,nacross,ndown
   use settings_render,  only:submenu_render,iplotcont_nomulti,icolours,double_rendering
   use settings_vecplot, only:submenu_vecplot,iplotpartvec
   use settings_xsecrot, only:submenu_xsecrotate,xsec_nomulti
+  use settings_units,   only:write_unitsfile
   use multiplot
   use prompting,        only:prompt,print_logical
   use transforms,       only:transform_label
@@ -55,9 +56,12 @@ subroutine menu
   integer            :: i,icol,ihalf,iadjust,indexi,ierr
   integer            :: ipicky,ipickx,irender,ivecplot,icontourplot
   integer            :: iamvecprev, ivecplottemp,ichoose
-  character(len=2)   :: ioption
+  integer            :: maxdigits
+  character(len=5)   :: ioption
   character(len=100) :: vecprompt,string
   character(len=20)  :: rprompt
+  character(len=2)   :: fmtstrlen
+  character(len=50)  :: fmtstr1,fmtstr2,fmtstr3
   character(len=*), parameter :: sep="(55('-'))"
   logical            :: iAllowRendering
 
@@ -127,12 +131,17 @@ subroutine menu
      print sep
      ihalf = numplot/2                ! print in two columns
      iadjust = mod(numplot,2)
-     print "(1x,i2,')',1x,a20,1x,i2,')',1x,a20)", &
+     maxdigits = floor(log10(real(maxplot)))+1
+     write(fmtstrlen,"(A1,I1)") "i",maxdigits
+     fmtstr1 = "(1x,"//trim(adjustl(fmtstrlen))//",')',1x,a20,1x," &
+                     //trim(adjustl(fmtstrlen))//",')',1x,a20)"
+     print fmtstr1, &
           (i,transform_label(label(i),itrans(i)), &
           ihalf + i + iadjust, transform_label(label(ihalf + i + iadjust), &
           itrans(ihalf+i+iadjust)),i=1,ihalf)
      if (iadjust.ne.0) then
-        print "(1x,i2,')',1x,a20)", &
+        fmtstr2 = "(1x,"//trim(adjustl(fmtstrlen))//",')',1x,a20)"
+        print fmtstr2, &
               ihalf + iadjust,transform_label(label(ihalf + iadjust), &
               itrans(ihalf+iadjust))
      endif
@@ -140,12 +149,15 @@ subroutine menu
 !--multiplot
 !
      print sep
-     print "(1x,i2,')',1x,a,'[ ',i2,' ]',5x,a2,') ',a)", &
+     fmtstr3 = "(1x,"//trim(adjustl(fmtstrlen))//",')',1x,a,'[ '," &
+                     //trim(adjustl(fmtstrlen))//",' ]',5x,a2,') ',a)"
+     print fmtstr3, &
            numplot+1,'multiplot ',nyplotmulti,'m','set multiplot '
   else
 !
 !--if no data
 !
+     maxdigits = 1
      print "(/a)",' No data: You may choose from the options below '
   endif
 !
@@ -167,14 +179,14 @@ subroutine menu
   read(*,"(a)",iostat=ierr) string
   if (ierr < 0) stop 'reached end of input' ! end of input (e.g. in script)
   if (ierr > 0) stop !'error reading input'
-  ioption = string(1:2)
+  ioption = string(1:maxdigits)
 
 !------------------------------------------------------------
 !  if input is an integer and within range, plot data
 !------------------------------------------------------------
   read(ioption,*,iostat=ierr) ipicky
   if (ierr /= 0) ipicky = -1
-  
+
   !--try to read more integers from the string
   !  if present, use these to set up an "instant multiplot"
   if (ipicky > 0 .and. ipicky < numplot+1 .and. len_trim(string) > 2) then
@@ -273,7 +285,11 @@ subroutine menu
                  call prompt('plot particles?',iplotpartvec)
               endif
            else
-              irender = 0
+              if (iAllowRendering) then
+                 call prompt('(render) (0=none)',irender,0,(numplot-nextra))
+              else
+                 irender = 0
+              endif
               ivecplot = 0
            endif
         elseif (ipicky > 0 .and. ipicky==itoomre .or. ipicky==isurfdens) then
@@ -397,6 +413,7 @@ subroutine menu
         endif
         call defaults_write(defaultsfile)
         call write_limits(limitsfile)
+        if (iRescale) call write_unitsfile(unitsfile,ncolumns)
 !------------------------------------------------------------------------
 !+ Slightly obsolete: prints whatever help may be helpful
      case('h','H')
@@ -667,7 +684,7 @@ logical function allowrendering(iplotx,iploty,xsec)
 !
  if ((ih.gt.0 .and. ih.le.ndataplots) &
     .and.(irho.gt.0 .and. irho.le.ndataplots) &
-    .and.(icoords.eq.icoordsnew .or. (.not.is_xsec .or. (xsec .and. islengthz))) &
+    .and.(icoords.eq.icoordsnew .or. (.not.is_xsec .or. (is_xsec .and. islengthz))) &
     .and.(itransx.eq.0 .and. itransy.eq.0)) then
 
     allowrendering = .true.
