@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2015 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -28,7 +28,7 @@ module settings_page
  use settings_limits, only:iadapt,iadaptcoords,adjustlimitstodevice,xminoffset_track,xmaxoffset_track
  use labels,          only:lenlabel
  implicit none
- integer :: iaxis,nacross,ndown,ipapersize,nstepsperpage,linewidth,iscalepanel
+ integer :: iaxis,nacross,ndown,ipapersize,nstepsperpage,linewidth,iscalepanel,linepalette
  integer :: iPlotLegendOnlyOnPanel,modlinestyle,modcolour,maxlinestyle,maxcolour
  integer :: iPageColours,ipapersizeunits
  logical :: iColourEachStep,iChangeStyles,tile,interactive,nomenu
@@ -42,6 +42,8 @@ module settings_page
  character(len=lenlabel) :: legendtext, scaletext
  character(len=60)       :: device
  character(len=lenlabel) :: labelyalt
+ integer, parameter :: maxc = 16
+ real    :: colourpalette(3,maxc)
 
  namelist /pageopts/ iaxis,nacross,ndown,interactive,iadapt,iadaptcoords, &
    nstepsperpage,iColourEachStep,iChangeStyles,tile,ipapersize,papersizex,aspectratio, &
@@ -51,7 +53,7 @@ module settings_page
    iPlotScale,dxscale,scaletext,hposscale,vposscale,iscalepanel,iUseBackgroundColourForAxes, &
    usesquarexy,maxlinestyle,modlinestyle,maxcolour,modcolour,usecolumnorder,ipapersizeunits,&
    adjustlimitstodevice,alphalegend,yscalealt,labelyalt,xminoffset_track,xmaxoffset_track, &
-   xminpagemargin,xmaxpagemargin,yminpagemargin,ymaxpagemargin
+   xminpagemargin,xmaxpagemargin,yminpagemargin,ymaxpagemargin,linepalette
 
 contains
 
@@ -61,7 +63,6 @@ contains
 subroutine defaults_set_page
   use shapes,  only:defaults_set_shapes
   use plotlib, only:plotlib_maxlinecolour
-  implicit none
 
   interactive = .true.     ! default for interactive mode
   iaxis = 0                ! turns axes off/on
@@ -93,6 +94,7 @@ subroutine defaults_set_page
   iPageColours = 0
   charheight = 1.0    ! character height
   linewidth = 0       ! line width
+  linepalette = 0
 
   iPlotScale = .false.
   hposscale = 0.5
@@ -116,6 +118,23 @@ subroutine defaults_set_page
   yminpagemargin = 0.
   ymaxpagemargin = 0.
 
+  colourpalette = reshape((/0.,0.,0., &
+                         0.933,0.173,0.173, &
+                         0.18,0.545,0.341,   &
+                         0., 0., 1.,         &
+                         0.192, 0.31, 0.31,  &
+                         0.58, 0., 0.827,    &
+                         0.0, 0.825, 0.825,  &
+                         1., 0.31, 0.,       &
+                         0.373, 0.62, 0.627, &
+                         0.933, 0.796, 0.678,&
+                         0.0, 1.0, 0.5,      &
+                         0.0, 0.5, 1.0,      &
+                         0.5, 0.0, 0.0,      &
+                         1.0, 0.0, 0.5,      &
+                         0.333, 0.333, 0.333,&
+                         0.667, 0.667, 0.667/),shape(colourpalette))
+
   return
 end subroutine defaults_set_page
 
@@ -123,7 +142,6 @@ end subroutine defaults_set_page
 ! changed default values for evsplash
 !---------------------------------------------
 subroutine defaults_set_page_ev
-  implicit none
 
   nstepsperpage   = 1000
   iColourEachStep = .true.   ! change colours if nstepsperpage > 1
@@ -134,20 +152,37 @@ subroutine defaults_set_page_ev
   vposlegend      = 2.0      ! vertical legend position in character heights
   fjustlegend     = 0.0      ! justification factor for legend
 
-  return
 end subroutine defaults_set_page_ev
 
+!---------------------------------------------
+! changed default values for 360 video
+!---------------------------------------------
+subroutine defaults_set_page_360
+
+  iPageColours = 2
+  iaxis = -2
+  ipapersize = 18
+  ipapersizeunits = 0
+  papersizex = 1080. !4320.
+  aspectratio = 0.5
+  iPageColours = 2
+  adjustlimitstodevice = .true.
+
+end subroutine defaults_set_page_360
+
 !----------------------------------------------------------------------
 ! submenu with options relating to page setup
 !----------------------------------------------------------------------
 subroutine submenu_page(ichoose)
  use params,      only:maxplot
  use prompting,   only:prompt,print_logical
- use pagecolours, only:pagecolourscheme,colour_fore,colour_back,maxpagecolours
- use plotlib,     only:plotlib_supports_alpha,plotlib_maxlinecolour,plotlib_maxlinestyle,plotlib_is_pgplot
- implicit none
+ use pagecolours, only:pagecolourscheme,colour_fore,colour_back,maxpagecolours,&
+                       write_coloursfile,read_coloursfile
+ use plotlib,     only:plotlib_supports_alpha,plotlib_maxlinecolour,plotlib_maxlinestyle,&
+                       plotlib_is_pgplot,plotlib_maxpalette
+ use filenames,   only:coloursfile
  integer, intent(in) :: ichoose
- integer             :: iaction,i,iunitsprev,ierr
+ integer             :: iaction,i,iunitsprev,ierr,nc
  real                :: papersizey,mnraslength
  character(len=15)   :: paperfmtstr
  character(len=3)    :: string
@@ -174,7 +209,7 @@ subroutine submenu_page(ichoose)
           "' 6) set character height                (',f4.1,')',/,"// &
           "' 7) adjust line width                   (',i2, ')',/,"// &
           "' 8) adjust page margins                 ( ',f4.1,' )',/,"// &
-          "' 9) set foreground/background colours   ( ',a,' )')", &
+          "' 9) set page and line colours           ( ',a,' )')", &
           nstepsperpage,iaxis,nacross,ndown,print_logical(tile), &
           trim(print_logical(usesquarexy)),charheight,linewidth,&
           xminpagemargin, &
@@ -230,6 +265,7 @@ subroutine submenu_page(ichoose)
      print*,' 2 : same as AXIS=1, but also draw grid lines at major increments of the coordinates;'
      print*,' 3 : draw box, ticks and numbers but no axes labels;'
      print*,' 4 : same as AXIS=0, but with a second y-axis scaled and labelled differently'
+     print*,' 5 : draw box, major ticks and numbers but no axes labels;'
      print*,'10 : draw box and label X-axis logarithmically;'
      print*,'20 : draw box and label Y-axis logarithmically;'
      print*,'30 : draw box and label both axes logarithmically.'
@@ -264,12 +300,14 @@ subroutine submenu_page(ichoose)
         print*,'15) 3840 x 2160 pixels (4KTV/Ultra HD)'
         print*,'16) 4096 x 2160 pixels (Cinema 4K)'
         print*,'17) 5120 x 2880 pixels (5K)'
-        print*,'18) 27320 x 3072 pixels (CAVE-2)'
-        print*,'19) 1/3 of A4 journal page  79mm x 180 mm'
-        print*,'20) 1/2 of A4 journal page 118mm x 180 mm'
-        print*,'21) full A4 journal page   236mm x 180 mm'
-        print*,'22) Custom size '
-        call prompt(' Enter option for paper size ',ipapersize,0,22)
+        print*,'18) 4320 x 2160 pixels (2160s)'
+        print*,'19) 8640 x 4320 pixels (4320s)'
+        print*,'20) 27320 x 3072 pixels (CAVE-2)'
+        print*,'21) 1/3 of A4 journal page  79mm x 180 mm'
+        print*,'22) 1/2 of A4 journal page 118mm x 180 mm'
+        print*,'23) full A4 journal page   236mm x 180 mm'
+        print*,'24) Custom size '
+        call prompt(' Enter option for paper size ',ipapersize,0,24)
      endif
      
      select case(ipapersize)
@@ -314,7 +352,7 @@ subroutine submenu_page(ichoose)
            papersizey = 600.
            aspectratio = papersizey/papersizex
         endif
-     case(8:21)
+     case(8:23)
         if (plotlib_is_pgplot) then
            ipapersizeunits = 1
            papersizex  = 0.  ! use PGPLOT default
@@ -354,24 +392,30 @@ subroutine submenu_page(ichoose)
               papersizex = 5120.
               papersizey = 2880.
            case(18)
+              papersizex = 4320.
+              papersizey = 2160.
+           case(19)
+              papersizex = 8640.
+              papersizey = 4320.
+           case(20)
               papersizex = 27320.
               papersizey = 3072.
-           case(19)  ! 1/3 of MNRAS page
+           case(21)  ! 1/3 of MNRAS page
               ipapersizeunits = 2
               papersizex = 18.
               papersizey = mnraslength/3.
-           case(20)  ! 1/2 of MNRAS page
+           case(22)  ! 1/2 of MNRAS page
               ipapersizeunits = 2
               papersizex = 18.
               papersizey = 0.5*mnraslength
-           case(21)  ! full MNRAS page, allowing 2cm for caption
+           case(23)  ! full MNRAS page, allowing 2cm for caption
               ipapersizeunits = 2
               papersizex = 18.
               papersizey = mnraslength - 2.
            end select
            aspectratio = papersizey/papersizex
         endif
-     case(22)
+     case(24)
         if (plotlib_is_pgplot) then
            ipapersizeunits = 1
            papersizex  = 0.  ! use PGPLOT default
@@ -471,6 +515,29 @@ subroutine submenu_page(ichoose)
         call prompt('Enter opacity for overlaid text and annotation ',alphalegend,0.0,1.0)
      endif
 
+     print "(9(/,a))",&
+       '-1: custom', &
+       ' 0: giza default line palette  ', &
+       ' 1: default PGPLOT line palette', &
+       ' 2: modified Tricco palette', &
+       ' 3: cheer up emo kid / grandma''s pillow', &
+       ' 4: outback desert moonscape',&
+       ' 5: colourblind safe line palette', &
+       ' 6: optimum line palette', &
+       ' 7: graph-a-licious'
+     call prompt('Enter line palette',linepalette,-1,plotlib_maxpalette)
+     if (linepalette < 0) then
+        call read_coloursfile(coloursfile,maxc,colourpalette,nc,ierr)
+        if (ierr /= 0 .or. nc <= 0) then
+           print*,' writing colours to file '//trim(coloursfile)
+           call write_coloursfile(trim(coloursfile),maxc,colourpalette)
+        else
+           print*,' colours written to file '//trim(coloursfile)
+        endif
+        print*,' edit this file to change the line palette'
+        print*,' ** press any key to continue **'
+        read*
+     endif
      return
   end select
 
@@ -485,7 +552,6 @@ subroutine submenu_legend(ichoose)
  use prompting, only:prompt,print_logical
  use shapes,    only:nshapes,labelshapetype,shape,submenu_shapes
  use legends,   only:prompt_panelselect
- implicit none
  integer, intent(in) :: ichoose
  integer             :: iaction,i,ierr,i1,i2
  character(len=50)   :: string
