@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2014 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -79,6 +79,17 @@ subroutine defaults_set_render
   return
 end subroutine defaults_set_render
 
+!---------------------------------------------
+! set default values for 360 video
+!---------------------------------------------
+subroutine defaults_set_render_360
+  use colourbar, only:set_floating_bar_style
+
+  iColourBarStyle = 7
+  call set_floating_bar_style(iColourBarStyle,4)
+
+end subroutine defaults_set_render_360
+
 !-----------------------------------------------------------------------------
 ! options for rendered plots
 !-----------------------------------------------------------------------------
