@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2015 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -682,9 +682,8 @@ contains
   logical, intent(out) :: gotbinary
   real :: rhozero,tfreefall,tff,radL1,PhiL1,Er,RK2,dtmax,tolh
   real :: massoftypei(ntypes)
-  integer :: i,ierrs(10),ipos
+  integer :: i,ierrs(10)
   integer :: itype
-  integer, parameter :: ilocbinary = 24
   real,    parameter :: pi=3.141592653589
   
   if (phantomdump) then
@@ -1092,7 +1091,7 @@ subroutine read_data(rootname,indexstart,iposn,nstepsread)
                       lowmemorymode,ntypes,iverbose,ndusttypes
   use mem_allocation, only:alloc
   use system_utils,   only:lenvironment,renvironment
-  use labels,         only:ipmass,irho,ih,ix,ivx,labeltype,print_types,idustfrac
+  use labels,         only:ipmass,irho,ih,ix,ivx,labeltype,print_types
   use calcquantities, only:calc_quantities
   use sphNGread
   implicit none
@@ -1504,9 +1503,9 @@ subroutine read_data(rootname,indexstart,iposn,nstepsread)
          enddo
          if (nint1(iarr).lt.1) then
             if (.not.phantomdump .or. any(npartoftypei(2:).gt.0)) then
-               print "(a)",' WARNING: can''t locate iphase in dump'
+               if (iverbose > 0) print "(a)",' WARNING: can''t locate iphase in dump'
             elseif (phantomdump) then
-               print "(a)",' WARNING: can''t locate iphase in dump'
+               if (iverbose > 0) print "(a)",' WARNING: can''t locate iphase in dump'
             endif
             gotiphase = .false.
             !--skip remaining integer arrays
@@ -2168,20 +2167,19 @@ end subroutine read_data
 subroutine set_labels
   use labels, only:label,unitslabel,labelzintegration,labeltype,labelvec,iamvec, &
               ix,ipmass,irho,ih,iutherm,ivx,iBfirst,idivB,iJfirst,icv,iradenergy,&
-              idustfrac,ideltav,idustfracsum,ideltavsum
+              idustfrac,ideltav,idustfracsum,ideltavsum,igrainsize,igraindens
   use params
-  use settings_data,   only:ndim,ndimV,ntypes,ncolumns,UseTypeInRenderings,debugmode,&
-                            ndusttypes
+  use settings_data,   only:ndim,ndimV,ntypes,ncolumns,UseTypeInRenderings,debugmode
   use geometry,        only:labelcoord
-  use settings_units,  only:units,unitzintegration
+  use settings_units,  only:units,unitzintegration,get_nearest_length_unit,get_nearest_time_unit
   use sphNGread
   use asciiutils,      only:lcase
   use system_commands, only:get_environment
   use system_utils,    only:lenvironment
   implicit none
   integer :: i,j
-  real(doub_prec)   :: uergg
-  character(len=20) :: string
+  real(doub_prec)   :: unitx
+  character(len=20) :: string,unitlabelx
   character(len=20) :: dustfrac_string,deltav_string
 
   if (ndim.le.0 .or. ndim.gt.3) then
@@ -2283,7 +2281,11 @@ subroutine set_labels
            label(i) = 'e^- abundance'
         case('abco')
            label(i) = 'CO abundance'
-        case default
+		case('grainsize')
+		   igrainsize = i
+		case('graindens')
+		   igraindens = i
+		case default
            if (debugmode) print "(a,i2)",' DEBUG: Unknown label '''//trim(tagarr(i))//''' in column ',i
            label(i) = tagarr(i)
         end select
@@ -2361,9 +2363,10 @@ subroutine set_labels
 !   npower = int(log10(udist))
 !   udist = udist/10.**npower
 !   udistAU = udist/1.495979e13
+   call get_nearest_length_unit(udist,unitx,unitlabelx)
    if (ndim.ge.3) then
-      units(1:3) = udist
-      unitslabel(1:3) = ' [cm]'
+      units(1:3) = unitx
+      unitslabel(1:3) = unitlabelx
    endif
 !   do i=1,3
 !      write(unitslabel(i),"('[ 10\u',i2,'\d cm]')") npower
@@ -2372,8 +2375,8 @@ subroutine set_labels
       units(ipmass) = umass
       unitslabel(ipmass) = ' [g]'
    endif
-   units(ih) = udist
-   unitslabel(ih) = ' [cm]'
+   units(ih) = unitx
+   unitslabel(ih) = unitlabelx
    if (ivx.gt.0) then
       units(ivx:ivx+ndimV-1) = udist/utime
       unitslabel(ivx:ivx+ndimV-1) = ' [cm/s]'
@@ -2396,6 +2399,14 @@ subroutine set_labels
       units(iBfirst:iBfirst+ndimV-1) = umagfd
       unitslabel(iBfirst:iBfirst+ndimV-1) = ' [G]'
    endif
+   if (igrainsize.gt.0) then
+	   units(igrainsize) = udist
+	   unitslabel(igrainsize) = ' [cm]'
+   endif
+   if (igraindens.gt.0) then
+	   units(igraindens) = umass/udist**3
+	   unitslabel(igraindens) = ' [g/cm\u3\d]'
+   endif
 
    !--use the following two lines for time in years
    call get_environment('SSPLASH_TIMEUNITS',string)
@@ -2420,12 +2431,9 @@ subroutine set_labels
       units(0) = 1./tfreefall
       unitslabel(0) = ' '
    case default
-      units(0) = utime/3.1536d7
-      unitslabel(0) = ' yrs'
+      call get_nearest_time_unit(utime,unitx,unitslabel(0))
+      units(0) = unitx ! convert to real*4
    end select
-   !--or use these two lines for time in free-fall times
-   !units(0) = 1./tfreefall
-   !unitslabel(0) = ' '
 
   unitzintegration = udist
   labelzintegration = ' [cm]'
