@@ -202,7 +202,7 @@ end subroutine timestep_loop
 ! works out whether or not we need to read another dump into memory
 !-------------------------------------------------------------------
 recursive subroutine get_nextstep(istep,ilocindat)
- use filenames,     only:nstepsinfile,nfiles,ifileopen,nsteps
+ use filenames,     only:nstepsinfile,nfiles,ifileopen,iposopen,nsteps
  use getdata,       only:get_data
  use settings_data, only:buffer_steps_in_file
  implicit none
@@ -237,8 +237,8 @@ recursive subroutine get_nextstep(istep,ilocindat)
     return
  endif
 
-! print*,'step ',istep,' in file ',ifile,' nsteps = ',nsteps
-! print*,'position in file = ',iposinfile
+ !print*,'step ',istep,' in file ',ifile,' nsteps = ',nsteps
+ !print*,'position in file = ',iposinfile
  if (istep.gt.nsteps) then
     ilocindat = 0
     return
@@ -270,11 +270,13 @@ recursive subroutine get_nextstep(istep,ilocindat)
        print*,'not enough steps in file... trying next file'
        call get_nextstep(istep,ilocindat)
     endif
- elseif (.not.buffer_steps_in_file) then
-    if (iposinfile <= nstepsinfile(ifile)) then
+ elseif (.not.buffer_steps_in_file .and. nstepsinfile(ifile) > 1) then
+    if (iposinfile <= nstepsinfile(ifile) .and. iposinfile /= iposopen) then
        ! if all steps have not been read from the file, read just the next one
        call get_data(ifile,.true.,iposinfile=iposinfile)
        ilocindat = 1
+    else
+       ilocindat = 1
     endif
  endif
 
@@ -288,7 +290,7 @@ end subroutine get_nextstep
 subroutine colour_timestep(istep,iChangeColours,iChangeStyles)
   use particle_data, only:icolourme
   use settings_part, only:linecolourthisstep,linestylethisstep,imarktype
-  use settings_page, only:maxlinestyle,modlinestyle,maxcolour,modcolour
+  use settings_page, only:maxlinestyle,modlinestyle,maxcolour,modcolour,linepalette
   use plotlib,       only:plotlib_maxlinestyle,plotlib_maxlinecolour
   implicit none
   integer, intent(in) :: istep
@@ -305,7 +307,14 @@ subroutine colour_timestep(istep,iChangeColours,iChangeStyles)
         endif
         icolour = mod(icolour-1,min(maxcolour,plotlib_maxlinecolour)) + 1
         icolourme = icolour
-        linecolourthisstep = icolour
+        if (linepalette < 0) then
+           ! for custom line colours do not use foreground/background colours - allow these to be changed
+           icolour = icolour + 1
+           icolourme = icolour
+           linecolourthisstep = icolour
+        else
+           linecolourthisstep = icolour
+        endif
      else
         print "(a)",'***error: array not allocated in colour_timestep***'
      endif
